#!/bin/env python3


import sys
import re

ROOT_FILE = sys.argv[1]
ROOT_CANDIDATES = []
with open(ROOT_FILE) as f:
    headers = None
    for line in f:
        cols = list(c.strip() for c in line.split('\t'))
        if headers is None:
            headers = cols
            continue
        record = dict(zip(headers, cols))
        if record['Taxonomy ID'] == '':
            sys.stderr.write('ignoring %s, not a taxon root\n' % (record['Name'],))
        else:
            ROOT_CANDIDATES.append((record['Name'], record['Taxonomy path']))

ROOTS = []
for name1, path1 in ROOT_CANDIDATES:
    accept = True
    for name2, path2 in ROOT_CANDIDATES:
        if path1 == path2 and name1 == path2:
            continue
        if path1.startswith(path2 + '/'):
            sys.stderr.write('%s excluded since it is subsumed by %s\n' % (name1, name2))
            accept = False
    if accept:
        sys.stderr.write('Root %s (%s)\n' % (name1, path1))
        ROOTS.append((name1, path1))

PATTERN = re.compile(r'\t(?:' + '|'.join(path for (name, path) in ROOTS) + r')[/\t]')
REMAIN = list(ROOTS)
for line in sys.stdin:
    m = PATTERN.search(line)
    if m is not None:
        sys.stdout.write(line)
        for name, path in REMAIN:
            if path in line:
                REMAIN.remove((name, path))
for name, path in REMAIN:
    sys.stderr.write('%s not seen' % (name,))
